@@ -11,6 +11,7 @@
 
 
 from __future__ import absolute_import
+import os
 
 __version__ = "develop"
 
@@ -61,9 +62,6 @@ from LAMP.models.sensor_spec import SensorSpec
 from LAMP.models.study import Study
 from LAMP.models.temporal_slice import TemporalSlice
 
-from LAMP.analysis.participant_ext import ParticipantExt
-from LAMP.analysis.study_ext import StudyExt
-
 API = APIApi()
 Type = TypeApi()
 Credential = CredentialApi()
@@ -77,7 +75,15 @@ Sensor = SensorEventApi()
 SensorSpec = SensorEventApi()
 SensorEvent = SensorEventApi()
 
-def connect(access_key, secret_key, server_address="api.lamp.digital"):
+def connect(access_key=None, secret_key=None, server_address=None):
+	if access_key is None and secret_key is None:
+		access_key = os.getenv('LAMP_ACCESS_KEY')
+		secret_key = os.getenv('LAMP_SECRET_KEY')
+	if server_address is None:  # let arg override environmental var
+		server_address = os.getenv('LAMP_SERVER_ADDRESS', 'api.lamp.digital')
+	if access_key is None or secret_key is None:
+		raise TypeError("connect() requires 2 positional arguments: 'access_key' and 'secret_key', unless environmental variables 'LAMP_ACCESS_KEY' and 'LAMP_SECRET_KEY' are provided")
+
 	client = ApiClient(Configuration(host=f"https://{server_address}", username=access_key, password=secret_key))
 
 	global API
